==> ejc-zjkjcost-api-3.0.0-20221019.075109-57-sources.jar: com/ejianc/business/zjkjcost/reserve/vo/AllocateExportVO.java <==
package com.ejianc.business.zjkjcost.reserve.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 风险预留金-项目部人员风险金预留分配表
 * 
 * @author generator
 * 
 */
@ApiModel("风险预留金-项目部人员风险金预留分配表")
public class AllocateExportVO{
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("单据编号")
    private String billCode;
    @ApiModelProperty("单据状态（审批必须字段）")
    private String billState;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("经办人名称")
    private String employeeName;
    @ApiModelProperty("创建时间")
    private String createTime;
    @ApiModelProperty("应预留风险金额")
    private String shouldReserveMny;
    @ApiModelProperty("实际预留风险金额")
    private String actualReserveMny;
    @ApiModelProperty("变更状态(1-未变更 2-变更中 3-已变更)")
    private String changeState;

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getBillState() {
        return billState;
    }

    public void setBillState(String billState) {
        this.billState = billState;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getShouldReserveMny() {
        return shouldReserveMny;
    }

    public void setShouldReserveMny(String shouldReserveMny) {
        this.shouldReserveMny = shouldReserveMny;
    }

    public String getActualReserveMny() {
        return actualReserveMny;
    }

    public void setActualReserveMny(String actualReserveMny) {
        this.actualReserveMny = actualReserveMny;
    }

    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
}

==> ejc-zjkjcost-api-3.0.0-20230510.105124-162-sources.jar: com/ejianc/business/zjkjcost/reserve/vo/AllocateExportVO.java <==
package com.ejianc.business.zjkjcost.reserve.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 风险预留金-项目部人员风险金预留分配表
 *
 * @author generator
 *
 */
@ApiModel("风险预留金-项目部人员风险金预留分配表")
public class AllocateExportVO{
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("单据编号")
    private String billCode;
    @ApiModelProperty("单据状态（审批必须字段）")
    private String billState;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("经办人名称")
    private String employeeName;
    @ApiModelProperty("创建时间")
    private String createTime;
    @ApiModelProperty("应预留风险金额")
    private String shouldReserveMny;
    @ApiModelProperty("实际预留风险金额")
    private String actualReserveMny;
    @ApiModelProperty("变更状态(1-未变更 2-变更中 3-已变更)")
    private String changeState;
    @ApiModelProperty("所属组织名称")
    private String orgName;

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getBillState() {
        return billState;
    }

    public void setBillState(String billState) {
        this.billState = billState;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getShouldReserveMny() {
        return shouldReserveMny;
    }

    public void setShouldReserveMny(String shouldReserveMny) {
        this.shouldReserveMny = shouldReserveMny;
    }

    public String getActualReserveMny() {
        return actualReserveMny;
    }

    public void setActualReserveMny(String actualReserveMny) {
        this.actualReserveMny = actualReserveMny;
    }

    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
}
